fn derived_parser_relation(
relation: &SymbolRelation,
target_name: String,
) -> SymbolRelationExpand description
Copy source context while replacing only the statically selected target.
fn derived_parser_relation(
relation: &SymbolRelation,
target_name: String,
) -> SymbolRelationCopy source context while replacing only the statically selected target.