fn derived_relation_facts(
graph: &SymbolGraph,
keys_by_relation: &BTreeMap<usize, &[CanonicalResolutionKey]>,
) -> Vec<DerivedRelationFact>Expand description
Derive additive families only from exact bounded parser facts and path policy.
fn derived_relation_facts(
graph: &SymbolGraph,
keys_by_relation: &BTreeMap<usize, &[CanonicalResolutionKey]>,
) -> Vec<DerivedRelationFact>Derive additive families only from exact bounded parser facts and path policy.