fn document_file_resolution_key(
project: ProjectInstanceId,
path: &str,
) -> Result<CanonicalResolutionKey, CliError>Expand description
Construct one exact file identity through the existing module-key domain.
fn document_file_resolution_key(
project: ProjectInstanceId,
path: &str,
) -> Result<CanonicalResolutionKey, CliError>Construct one exact file identity through the existing module-key domain.