fn entity_owner_path(entity: &GraphEntity) -> Option<&str>Expand description
Return the source-owner path for entities eligible to export graph keys.
fn entity_owner_path(entity: &GraphEntity) -> Option<&str>Return the source-owner path for entities eligible to export graph keys.