fn entity_retained_bytes(entity: &GraphEntity) -> u64Expand description
Count conservative fixed and variable bytes retained by one graph entity.
fn entity_retained_bytes(entity: &GraphEntity) -> u64Count conservative fixed and variable bytes retained by one graph entity.