fn identity_fact_owner(
fields: &[(GraphIdentityField, GraphIdentityRejectionReason)],
) -> u8Expand description
Map one rejection field to the admission owner that re-derives it.
fn identity_fact_owner(
fields: &[(GraphIdentityField, GraphIdentityRejectionReason)],
) -> u8Map one rejection field to the admission owner that re-derives it.