fn is_rederived_identity_fact(fact: &IdentityFactKey) -> boolExpand description
Return whether a persisted fact is replaced by the current derivation.
fn is_rederived_identity_fact(fact: &IdentityFactKey) -> boolReturn whether a persisted fact is replaced by the current derivation.