fn next_generation(base: IndexGeneration) -> Result<IndexGeneration, CliError>Expand description
Return the pending graph generation after one successful publication.
fn next_generation(base: IndexGeneration) -> Result<IndexGeneration, CliError>Return the pending graph generation after one successful publication.