fn record_identity_failure(
failures: &mut Vec<(GraphIdentityField, GraphIdentityRejectionReason)>,
field: GraphIdentityField,
value: &str,
)Expand description
Validate one source identity without retaining the rejected raw value.
fn record_identity_failure(
failures: &mut Vec<(GraphIdentityField, GraphIdentityRejectionReason)>,
field: GraphIdentityField,
value: &str,
)Validate one source identity without retaining the rejected raw value.