fn resolution_projection_fact_index(
report: &GraphIdentityAdmission,
path: &str,
fact: ResolutionProjectionFact,
) -> u64Expand description
Map one resolution fact into its deterministic internal rejection identity.
fn resolution_projection_fact_index(
report: &GraphIdentityAdmission,
path: &str,
fact: ResolutionProjectionFact,
) -> u64Map one resolution fact into its deterministic internal rejection identity.