fn resolution_projection_map_entry_retained_bytes(
path: &str,
projection: &ResolutionKeyProjection,
) -> u64Expand description
Count one admitted projection entry while it remains in the source map.
fn resolution_projection_map_entry_retained_bytes(
path: &str,
projection: &ResolutionKeyProjection,
) -> u64Count one admitted projection entry while it remains in the source map.