fn resolution_projection_map_retained_bytes(
projections: &BTreeMap<String, ResolutionKeyProjection>,
) -> u64Expand description
Count all projection-map entries that coexist with the growing entity state.
fn resolution_projection_map_retained_bytes(
projections: &BTreeMap<String, ResolutionKeyProjection>,
) -> u64Count all projection-map entries that coexist with the growing entity state.