fn resolution_registry_from_exports(
projection: &EntityProjection,
control: &IndexWorkControl,
) -> Result<ProjectResolutionRegistry, CliError>Expand description
Build current resolution candidates from newly staged entity exports.
fn resolution_registry_from_exports(
projection: &EntityProjection,
control: &IndexWorkControl,
) -> Result<ProjectResolutionRegistry, CliError>Build current resolution candidates from newly staged entity exports.