fn selected_project(store: &AtlasStore) -> Result<ProjectInstanceId, CliError>Expand description
Load the project identity required by normalized graph projection.
fn selected_project(store: &AtlasStore) -> Result<ProjectInstanceId, CliError>Load the project identity required by normalized graph projection.