fn sort_dedup_dependencies(dependencies: &mut Vec<RelationDependencyKey>)Expand description
Sort and deduplicate relation dependency bindings by canonical key and owner.
fn sort_dedup_dependencies(dependencies: &mut Vec<RelationDependencyKey>)Sort and deduplicate relation dependency bindings by canonical key and owner.