fn source_symbol_identity_error(value: &str) -> Result<(), GraphContractError>Expand description
Validate one source identity without allocating on the valid hot path.
fn source_symbol_identity_error(value: &str) -> Result<(), GraphContractError>Validate one source identity without allocating on the valid hot path.