fn static_data_access_kind(target: &str) -> Option<ExtendedRelationKind>Expand description
Classify a call as one accepted bounded static read or write API.
fn static_data_access_kind(target: &str) -> Option<ExtendedRelationKind>Classify a call as one accepted bounded static read or write API.