struct GraphOwners {
file_digest: String,
symbol_digests: Vec<Option<String>>,
}Expand description
File and symbol entities associated with one parser graph.
Fields
file_digest: StringDigest of the file entity owning the parser graph.
symbol_digests: Vec<Option<String>>Optional stable entity digest corresponding to each parser symbol row.