struct IdentitySpan {
start_line: usize,
start_column: usize,
end_line: usize,
end_column: usize,
}Expand description
Bounded source span attached to one rejected parser identity.
Fields
start_line: usizeOne-based first line containing the parser fact.
start_column: usizeZero-based first column when the parser provides one.
end_line: usizeOne-based last line containing the parser fact.
end_column: usizeZero-based exclusive end column when the parser provides one.